function [fc0,fc1]=coreforce(MU,NU,b,r0,r1,a,a0,flag)

% Computes driving force on two end nodes of a segment due to self stress
% MU is shear modulus, NU is Poisson ratio, b(3) is Burgers vector
% r0(3) is position of one node, r1(3) is position of the other node
% a is core spread radius
%
% For debugging purposes,
% if flag == 1, only radial component is included
% if flag == 2, only theta component is included
% otherwise both components are included


[mb,nb]=size(b); [m0,n0]=size(r0); [m1,n1]=size(r1); 
if (mb<nb) | (m0<n0) | (m1<n1)
    disp('selfforce: b, r0, r1 should be column vector');
end

r01=r1-r0; L01=norm(r01); e01=r01/L01;

%screw Burgers vector
bs=dot(b,e01); 

%edge Burgers vector
be=b-bs*e01;

Ecore = MU/4/pi * (bs^2 + sum(be.*be)/(1-NU)) * log(a/a0);
%ft = -MU*bs*be*2*NU/L01/4/pi/(1-NU) * log(a/a0) * 26.17;
ft = -MU*bs*be*2*NU/4/pi/(1-NU) * log(a/a0);

fr = Ecore*e01;

if flag==1
   ft=0;
elseif flag==2
   fr=0;
elseif flag==3
   ft=0;
   Ecore=MU/4/pi * ( bs^2*(1+NU)/(1-NU) + sum(be.*be)*(1-2*NU)/(1-NU)) * log(a/a0);
   fr = Ecore*e01;
end

fc0= ft+fr;
fc1= -fc0;

