function E = elasticenergy(MU,NU,a,rn,links)
%compute total elastic energy of dislocation network
%Input
%  MU: shear modulus
%  NU: Poisson ratio
%  a:  core spread width
%  rn: nodal position
%  links: dislocation segments (node indices and Burgers vector)
%
%Output
%  E:  total elastic energy of the dislocation structure
%
%Data structure of input arrays:
%  rn:      (NMAX,nr)    nr>=3  array of nodal positions (x,y,z,...)
%  links:   (LINKMAX,nl) nl>=5, array of links (id1,id2,bx,by,bz,...)

[NMAX,m]=size(rn);
if(m<3)
    disp('rn should have at least 3 columns!');
    return;
end
[LINKMAX,m]=size(links);

%self energy
Es=0; 
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        b=links(i,3:5)';
        W=engself(MU,NU,b,rn(n0,1:3)',rn(n1,1:3)',0,a);
        Es=Es+W;
    end
end

%interaction energy
Eint=0;
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        b01=links(i,3:5)';
        for j=i+1:LINKMAX,
            n2=links(j,1);
            n3=links(j,2);
            if(n2~=0)&(n3~=0)
                b23=links(j,3:5)';
                W=enginteract(MU,NU,b01,b23,rn(n0,1:3)',rn(n1,1:3)',...
                    rn(n2,1:3)',rn(n3,1:3)',a);
                Eint=Eint+W;
            end
        end
    end
end

%total energy
E=Es+Eint;
