function W=enginteract(MU,NU,b1,b2,r1,r2,r3,r4,a)
% Computes interaction energy between two straight dislocation segments
% r1-r2 (Burgers vector b1) and r3-r4 (Burgers vector b2)
% MU is shear modulus, NU is Poisson ratio, a is core spread radius

r21=r2-r1;
r43=r4-r3;
r31=r3-r1;

%make sure dr1, dr2 are column vector
s1=size(r21); if(s1(1)==1) r21=r21'; end
s2=size(r43); if(s2(1)==1) r43=r43'; end
s3=size(r31); if(s3(1)==1) r31=r31'; end

e1=r21/norm(r21);
e2=r43/norm(r43);

e3=cross(e1,e2);
subzero=1e-10;

if(norm(e3)<subzero)
  e2a=schmidt(r31,e1);
  e3=cross(e1,e2a);
  eta=(dot(r3-r1,e2a)+dot(r4-r1,e2a))/2;
  x1=0; x2=dot(r2-r1,e1);
  y1=dot(r3-r1,e1); y2=dot(r4-r1,e1);
  %engparallelb2 do not rotate b, need to do it here
  M=[e1,e2a,e3]; b1n=M'*b1; b2n=M'*b2;
  W=engparallelb2(MU,NU,b1n,b2n,x1,x2,y1,y2,eta,a);
else
  costheta=dot(e1,e2);
  e3=e3/norm(e3);
  e2a=cross(e3,e1);
  z=dot(r31,e3);  
  z=-z;
  %A=[r21(1:2),-r43(1:2)];rhs=r31(1:2);
  A=[[dot(r21,e1);dot(r21,e2a)],-[dot(r43,e1);dot(r43,e2a)]];rhs=[dot(r31,e1);dot(r31,e2a)];
  t=A\rhs;
  r0=(1-t(1))*r1+t(1)*r2;
  x1=dot(r1-r0,e1); x2=dot(r2-r0,e1);
  y1=dot(r3-r0,e2); y2=dot(r4-r0,e2);
  W=engnonplanarb2(MU,NU,b1,b2,e1,e2,e3,costheta,x1,x2,y1,y2,z,a);  
end
