function [f0,f1,f2]=hingeforce_strint(MU,NU,b1,b2,r0,r1,r2,a,nsub)
% Computes force on three nodes r0-r1-r2 forming a hinge 
% Burgers vector of segment r0-r1 is b1, Burgers vector of segment r1-r2 is b2
% MU is shear modulus, NU is Poisson ratio, a is core spread radius
% nsub is the subdivision points for numerical integration
% Geometry:
% r0--------r1--------r2

[mb,nb]=size(b1); [m0,n0]=size(r0); [m1,n1]=size(r1); [m2,n2]=size(r2);
if (mb<nb) | (m0<n0) | (m1<n1) | (m2<n2)
    disp('selfforce: b, r0, r1 should be column vector');
end

r01=r1-r0; L01=norm(r01); e01=r01/L01;
r12=r2-r1; L12=norm(r12); e12=r12/L12;
alpha=([1:nsub]-0.5)/nsub;

strL01=zeros(nsub,3,3);
strL12=zeros(nsub,3,3);

for i=1:nsub
    r=r0+(r1-r0)*alpha(i);
    %Original implementation (easier to read)
    %s=calsegstr3da(MU, NU, b2, r1, r2, r, a);
    %A faster implementation
    s=calsegstr3dt(MU, NU, b2, r1, r2, r, a);
    strL01(i,:,:)=s;
end

for i=1:nsub
    r=r1+(r2-r1)*alpha(i);
    %Original implmentation
    %s=calsegstr3da(MU, NU, b1, r0, r1, r, a);
    %A faster implementation
    s=calsegstr3dt(MU, NU, b1, r0, r1, r, a);
    strL12(i,:,:)=s;
end

s0=zeros(3,3); s01=s0; s12=s0; s2=s0;
for i=1:nsub,
    for j=1:3, for k=1:3,
    s0(j,k)=s0(j,k)+strL01(i,j,k)*(1-alpha(i));
    s01(j,k)=s01(j,k)+strL01(i,j,k)*alpha(i);
    s12(j,k)=s12(j,k)+strL12(i,j,k)*(1-alpha(i));
    s2(j,k)=s2(j,k)+strL12(i,j,k)*alpha(i);
    end; end
end

f0=cross(s0*b1,r01)/nsub;
f1=cross(s01*b1,r01)/nsub+cross(s12*b2,r12)/nsub;
f2=cross(s2*b2,r12)/nsub;
