function E=loopenergy(MU,NU,b,rn,a)
%compute total elastic energy of a dislocation loop
%Input
%  MU: shear modulus
%  NU: Poisson ratio
%  a:  core spread width
%  rn: nodal position array (N,nr) nr>=3  array of nodal positions (x,y,z,...)
%
%Output
%  E:  total elastic energy of the dislocation loop

%N: number of nodes
[N,nr]=size(rn);
if(nr<3)
    disp('r should have at least 3 columns!');
    return;
end

%total energy
E=0; Es=0; Eint=0;

%cut-off radius (compatibility with previous singular expression)
rho=0;

%self energy
for i1=1:N,
    i0=mod(i1-2+N,N)+1;
    Ws=engself(MU,NU,b,rn(i0,:)',rn(i1,:)',rho,a);
    Es=Es+Ws;
    %consistency test
    %Wp=0.5*enginteract(MU,NU,b,b,rn(i0,:)',rn(i1,:)',rn(i0,:)',rn(i1,:)',a);
    %disp(sprintf('Ws=%25.15e We=%25.15e',Ws,Wp));
end

%interaction energy
for i1=1:N,
    i0=mod(i1-2+N,N)+1;
    for j=i0+1:i0+N-1,
        i2=mod(j-1,N)+1;
        i3=mod(j  ,N)+1;
        W=enginteract(MU,NU,b,b,rn(i0,:)',rn(i1,:)',rn(i2,:)',rn(i3,:)',a);
        Eint=Eint+W;
    end
end
E=real(Es+Eint/2);
