function fn=loopnodeforce_analyt(MU,NU,b,rn,a)
% Computes driving force on all nodes in a dislocation loop,
% by analytic segment stress integration along another segment.
% The loop is specified by an array of node positions: rn.
% The segment from each node to the next one has Burgers vector b.
% MU is shear modulus, NU is Poisson ratio, a is core spread radius.
%
% Uses function: selfforce, remoteforce_analyt
fn=zeros(size(rn));

%N: number of nodes
[N,m]=size(rn);
if(m~=3)
    disp('r should have 3 columns!');
    return;
end

fs=fn; %self force   (contribution from self stress)
fm=fn; %remote force (contribution from far away segment)

%self force
for i1=1:N,
    i0=mod(i1-2+N,N)+1;
    [f0,f1]=selfforce(MU,NU,b,rn(i0,:)',rn(i1,:)',a);
    fs(i0,:)=fs(i0,:)+f0';
    fs(i1,:)=fs(i1,:)+f1';
end

%remote force
for i1=1:N,
    if(mod(i1,10)==0)
        disp(sprintf('i1=%d/%d',i1,N));
    end
    i0=mod(i1-2+N,N)+1;
    for j=i0+1:i0+N-1,
        i2=mod(j-1,N)+1;
        i3=mod(j  ,N)+1;
        if(i2>i0)
        [f0,f1,f2,f3]=remoteforce_analyt(MU,NU,b,rn(i0,:)',rn(i1,:)',b,rn(i2,:)',rn(i3,:)',a);
        fm(i0,:)=fm(i0,:)+f0';
        fm(i1,:)=fm(i1,:)+f1';
        fm(i2,:)=fm(i2,:)+f2';
        fm(i3,:)=fm(i3,:)+f3';
        end
    end
end

fn=fs+fm;