function fn=loopnodeforce_engdif(MU,NU,b,rn,a,i,Delta)
% Computes driving force on all nodes (for i==0) in a dislocation loop,
% by finite difference of elastic energy.
% The loop is specified by an array of node positions: rn.
% The segment from each node to the next one has Burgers vector b.
% MU is shear modulus, NU is Poisson ratio, a is core spread radius.
% Delta is the step size of finite difference.
% For i>0, only the force for node i is computed

fn=zeros(size(rn));

%N: number of nodes
[N,m]=size(rn);
if(m~=3)
    disp('r should have 3 columns!');
    return;
end

rh=rn;

if(i==0)
   for i=1:N,
      for j=1:3,
         rh(i,j)=rn(i,j)+Delta; E2=loopenergy(MU,NU,b,rh,a);
         rh(i,j)=rn(i,j)-Delta; E1=loopenergy(MU,NU,b,rh,a);
         fn(i,j)=-(E2-E1)/(Delta*2);
         rh(i,j)=rn(i,j);
      end
   end
else
   if(i<0)|(i>N)
      printf('loopnodeforce_engdif: invalid i=%d\n',i);
      return;
   end   
   fn=[0 0 0];
   for j=1:3,
      rh(i,j)=rn(i,j)+Delta; E2=loopenergy(MU,NU,b,rh,a);
      rh(i,j)=rn(i,j)-Delta; E1=loopenergy(MU,NU,b,rh,a);
      fn(j)=-(E2-E1)/(Delta*2);
      rh(i,j)=rn(i,j);      
   end
end

