function fn=loopnodeforce_strint(MU,NU,b,rn,a,nsub,nsubn)
% Computes driving force on all nodes in a dislocation loop,
% by numerically integrating stress on dislocation segments.
% The loop is specified by an array of node positions: rn.
% The segment from each node to the next one has Burgers vector b.
% MU is shear modulus, NU is Poisson ratio, a is core spread radius.
% nsub is the subdivision points on a segment when integrating 
%    the stress field from remote segments.
% nsubn is the subdivision points on a segment when integrating
%    the stress field from its two neighboring segments.
% The contribution from self stress field is computed from analytic
%    expressions.
%
% Uses function: selfforce, hingeforce_strint, remoteforce_strint
fn=zeros(size(rn));

%N: number of nodes
[N,m]=size(rn);
if(m~=3)
    disp('r should have 3 columns!');
    return;
end

fh=fn; %hinge force  (contribution from neighboring segment)
fs=fn; %self force   (contribution from self stress)
fm=fn; %remote force (contribution from far away segment)

%self force
for i1=1:N,
    i0=mod(i1-2+N,N)+1;
    [f0,f1]=selfforce(MU,NU,b,rn(i0,:)',rn(i1,:)',a);
    fs(i0,:)=fs(i0,:)+f0';
    fs(i1,:)=fs(i1,:)+f1';
    %if(0)%debug self force
    %    disp(sprintf('self force(a) %20.10e %20.10e %20.10e',...
    %        f0(1),f0(2),f0(3))); 
    %    [f0,f1]=remoteforce_strint(MU,NU,b,rn(i0,:)',rn(i1,:)',b,rn(i0,:)',rn(i1,:)',a,100);
    %    disp(sprintf('self force(b) %20.10e %20.10e %20.10e\n',...
    %        f0(1),f0(2),f0(3))); 
    %end
end

%hinge force
for i1=1:N,
    i0=mod(i1-2+N,N)+1;
    i2=mod(i1,N)+1;
    
    %explicit integration of hinge node
    [f0,f1,f2]=hingeforce_strint(MU,NU,b,b,rn(i0,:)',rn(i1,:)',rn(i2,:)',a,nsubn);
    %
    %smart algorithm: use translational invaraince of energy (not provided here)
    %[f0,f1,f2]=hingeforceEb2(MU,NU,b,b,rn(i0,:)',rn(i1,:)',rn(i2,:)',a,nsubn);

    fh(i0,:)=fh(i0,:)+f0';
    fh(i1,:)=fh(i1,:)+f1';
    fh(i2,:)=fh(i2,:)+f2';
end

%remote force
for i1=1:N,
    if(mod(i1,10)==0)
        disp(sprintf('i1=%d/%d',i1,N));
    end
    i0=mod(i1-2+N,N)+1;
    for j=i0+2:i0+N-2,
        i2=mod(j-1,N)+1;
        i3=mod(j  ,N)+1;
        [f0,f1]=remoteforce_strint(MU,NU,b,rn(i0,:)',rn(i1,:)',b,rn(i2,:)',rn(i3,:)',a,nsub);
        fm(i0,:)=fm(i0,:)+f0';
        fm(i1,:)=fm(i1,:)+f1';
    end
end

fn=fh+fs+fm;