function fn=nodeforce_analyt(MU,NU,a,rn,links,sigext)
% Computes driving force on all nodes in an arbitrary dislocation network
% by analytic segment stress integration along another segment.
% The loop is specified by two arrays: rn and links (see elasticenergy.m)
% MU is shear modulus, NU is Poisson ratio, a is core spread radius.
% sigext is the externally applied stress

%NMAX: max number of nodes
[NMAX,m]=size(rn);
if(m<3)
    disp('rn should have at least 3 columns!');
    return;
end
[LINKMAX,m]=size(links);

%initialize nodal force array
fn=zeros(NMAX,3);

%PK force due to applied stress
fp=fn;
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        b=links(i,3:5)';
        f=pkforce(sigext,b,rn(n0,1:3)',rn(n1,1:3)');
        fp(n0,:)=fp(n0,:)+0.5*f';
        fp(n1,:)=fp(n1,:)+0.5*f';
    end
end


%self force
fs=fn;
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        b=links(i,3:5)';
        [f0,f1]=selfforce(MU,NU,b,rn(n0,1:3)',rn(n1,1:3)',a);
        fs(n0,:)=fs(n0,:)+f0';
        fs(n1,:)=fs(n1,:)+f1';
    end
end


%remote force
fr=fn; 
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        r0=rn(n0,1:3)';r1=rn(n1,1:3)';
        b01=links(i,3:5)';
        for j=i+1:LINKMAX,
            n2=links(j,1);
            n3=links(j,2);
            if(n2~=0)&(n3~=0)
                r2=rn(n2,1:3)';r3=rn(n3,1:3)';
                b23=links(j,3:5)';
                if(1)
                    [f0,f1,f2,f3]=remoteforce_analyt(MU,NU,b01,r0,r1,b23,r2,r3,a);
                    fr(n0,:)=fr(n0,:)+f0';
                    fr(n1,:)=fr(n1,:)+f1';
                    fr(n2,:)=fr(n2,:)+f2';
                    fr(n3,:)=fr(n3,:)+f3';
                 end            
            end
        end
    end
end

%total force
fn=fp+fs+fr;
