function fn=nodeforce_engdif(MU,NU,a,rn,links,i,Delta)
% Computes driving force on all nodes (for i==0) in an arbitrary
% dislocation network by finite difference of elastic energy.
% The dislocation is specified by two arrays: rn and links
% See elasticenergy for explanation of rn and links.
% MU is shear modulus, NU is Poisson ratio, a is core spread radius.
% Delta is the step size of finite difference.
% For i>0, only the force for node i is computed

fn=zeros(size(rn));

%N: number of nodes
[N,m]=size(rn);
if(m<3)
    disp('r should have at least 3 columns!');
    return;
end

rh=rn;
if(i==0)
   for i=1:N,
      for j=1:3,
         rh(i,j)=rn(i,j)+Delta; E2=elasticenergy(MU,NU,a,rh,links);
         rh(i,j)=rn(i,j)-Delta; E1=elasticenergy(MU,NU,a,rh,links);
         fn(j)=-(E2-E1)/(Delta*2);
         rh(i,j)=rn(i,j);
      end
   end
else
   if(i<0)|(i>N)
      printf('nodeforce_engdif: invalid i=%d\n',i);
      return;
   end   
   fn=[0 0 0];
   for j=1:3,
      rh(i,j)=rn(i,j)+Delta; E2=elasticenergy(MU,NU,a,rh,links);
      rh(i,j)=rn(i,j)-Delta; E1=elasticenergy(MU,NU,a,rh,links);
      fn(j)=-(E2-E1)/(Delta*2);
      rh(i,j)=rn(i,j);
   end
end