function fn=nodeforce_strint(MU,NU,a,rn,links,nsub,nsubn,sigext)
%compute nodal driving force of dislocation network by stress formula
%(serial version)
%rn: nodal position
%links: dislocation segments (connectivity, Burgers vector)
%nsub:  subdivision points for stress integration
%nsubn: subdivision points for neighboring segments
%sigext: external stress (applied)

%NMAX: max number of nodes
[NMAX,m]=size(rn);
if(m<3)
    disp('rn should have at least 3 columns!');
    return;
end
[LINKMAX,m]=size(links);

%initialize nodal force array
fn=zeros(NMAX,3);

%PK force due to applied stress
fp=fn;
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        b=links(i,3:5)';
        f=pkforce(sigext,b,rn(n0,1:3)',rn(n1,1:3)');
        fp(n0,:)=fp(n0,:)+0.5*f';
        fp(n1,:)=fp(n1,:)+0.5*f';
    end
end


%self force
fs=fn;
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        b=links(i,3:5)';
        [f0,f1]=selfforce(MU,NU,b,rn(n0,1:3)',rn(n1,1:3)',a);
        fs(n0,:)=fs(n0,:)+f0';
        fs(n1,:)=fs(n1,:)+f1';
    end
end

%hinge force
fh=fn;
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        r0=rn(n0,1:3)';r1=rn(n1,1:3)';
        b01=links(i,3:5)';
        for j=i+1:LINKMAX,
            n2=links(j,1);
            n3=links(j,2);
            if(n2~=0)&(n3~=0)
                r2=rn(n2,1:3)';r3=rn(n3,1:3)';
                b23=links(j,3:5)';
                if(n0==n2)|(n0==n3)|(n1==n2)|(n1==n3)
                 if(n1==n2)
                    %[f0,f1,f3]=hingeforceEb2(MU,NU,b01,b23,r0,r1,r3,a,nsubn);
                    [f0,f1,f3]=hingeforce_strint(MU,NU,b01,b23,r0,r1,r3,a,nsubn);
                    fh(n0,:)=fh(n0,:)+f0';fh(n1,:)=fh(n1,:)+f1';fh(n3,:)=fh(n3,:)+f3';
                 elseif(n1==n3)
                    %[f0,f1,f2]=hingeforceEb2(MU,NU,b01,-b23,r0,r1,r2,a,nsubn);
                    [f0,f1,f2]=hingeforce_strint(MU,NU,b01,-b23,r0,r1,r2,a,nsubn);
                    fh(n0,:)=fh(n0,:)+f0';fh(n1,:)=fh(n1,:)+f1';fh(n2,:)=fh(n2,:)+f2';
                 elseif(n0==n2)
                    %[f1,f0,f3]=hingeforceEb2(MU,NU,-b01,b23,r1,r0,r3,a,nsubn);
                    [f1,f0,f3]=hingeforce_strint(MU,NU,-b01,b23,r1,r0,r3,a,nsubn);
                    fh(n0,:)=fh(n0,:)+f0';fh(n1,:)=fh(n1,:)+f1';fh(n3,:)=fh(n3,:)+f3';
                 elseif(n0==n3)
                    %[f1,f0,f2]=hingeforceEb2(MU,NU,-b01,-b23,r1,r0,r2,a,nsubn);
                    [f1,f0,f2]=hingeforce_strint(MU,NU,-b01,-b23,r1,r0,r2,a,nsubn);
                    fh(n0,:)=fh(n0,:)+f0';fh(n1,:)=fh(n1,:)+f1';fh(n2,:)=fh(n2,:)+f2';
                 end
                end
            end
        end
    end
end

%remote force
fr=fn; 
for i=1:LINKMAX,
    n0=links(i,1);
    n1=links(i,2);
    if(n0~=0)&(n1~=0)
        r0=rn(n0,1:3)';r1=rn(n1,1:3)';
        b01=links(i,3:5)';
        for j=1:LINKMAX,
           if(i~=j) 
            n2=links(j,1);
            n3=links(j,2);
            if(n2~=0)&(n3~=0)
                r2=rn(n2,1:3)';r3=rn(n3,1:3)';
                b23=links(j,3:5)';
                if(n0~=n2)&(n0~=n3)&(n1~=n2)&(n1~=n3)
                    [f0,f1]=remoteforce_strint(MU,NU,b01,r0,r1,b23,r2,r3,a,nsub);
                    fr(n0,:)=fr(n0,:)+f0';
                    fr(n1,:)=fr(n1,:)+f1';
                end            
             end
            end
        end
    end
end

%total force
fn=fp+fs+fh+fr;
