function [f1,f2,f3,f4]=remoteforce_analyt_special(mu,nu,bp,x1,x2,b,x3,x4,a)
% this calculates the forces between dislocation nodes analytically
% this is a special subroutine used for dislocation segments that are too close to parallel to be
% calculated by the regular expression for forces
%inputs: endpoints of first dislocation segment starting at x1 ending at x2 with burgers vector bp
%        endpoints of second dislocation segment starting at x3 ending at x4 with burgers vector b
%        core paramter a
%        shear modulus mu
%        poisson ration nu
%
%outputs: f1,f2,f3,f4 is the force on nodes located at x1, x2, x3, x4 respectively

     eps=1e-5;
    
     Diff=x4-x3;
     L=sqrt(sum(Diff.*Diff,2));
     t=Diff./[L L L];
   
     R=(x3-x1);
     nd=[R(:,2).*t(:,3)-R(:,3).*t(:,2) , R(:,3).*t(:,1)-R(:,1).*t(:,3) , R(:,1).*t(:,2)-R(:,2).*t(:,1)];
     
     d=sqrt(sum(nd.*nd,2));
     for i=1:size(d,1)
        if d(i) < eps
            % dislocations are colinear
            % must do something extra special
            testv=rand(1,3);
            nd(i,:)=[testv(2).*t(i,3)-testv(3).*t(i,2) , testv(3).*t(i,1)-testv(1).*t(i,3) , testv(1).*t(i,2)-testv(2).*t(i,1)];
            d(i)=sqrt(sum(nd(i,:).*nd(i,:),2));
        end
    end
     n=nd./[d d d];
     binormal=[n(:,2).*t(:,3)-n(:,3).*t(:,2) , n(:,3).*t(:,1)-n(:,1).*t(:,3) , n(:,1).*t(:,2)-n(:,2).*t(:,1)];
     
     disp=sqrt(eps);
     temp1=(10*disp).*L;
     delta=[temp1 temp1 temp1].*binormal;
     
     x40=x4+delta;
     %[f1a,f2a,f3a,f4a]=RemoteNodeForce(x1,x2,x3,x40,bp,b,a,mu,nu);
     [f1a,f2a,f3a,f4a]=remoteforce_analyt(mu,nu,bp,x1,x2,b,x3,x40,a);
     
     
     x40=x4-delta;
     %[f1b,f2b,f3b,f4b]=RemoteNodeForce(x1,x2,x3,x40,bp,b,a,mu,nu);
     [f1b,f2b,f3b,f4b]=remoteforce_analyt(mu,nu,bp,x1,x2,b,x3,x40,a);
     
     f1=(f1a+f1b).*0.5;
     f2=(f2a+f2b).*0.5;
     f3=(f3a+f3b).*0.5;
     f4=(f4a+f4b).*0.5;
     