function [f1,f2,f3,f4]=remoteforce_analyt_special3(mu,nu,bp,x1,x2,b,x3,x4,a)
% this calculates the forces between dislocation nodes analytically
% this is a special subroutine used for dislocation segments that are too close to parallel to be
% calculated by the regular expression for forces
%inputs: endpoints of first dislocation segment starting at x1 ending at x2 with burgers vector bp
%        endpoints of second dislocation segment starting at x3 ending at x4 with burgers vector b
%        core paramter a
%        shear modulus mu
%        poisson ration nu
%
%outputs: f1,f2,f3,f4 is the force on nodes located at x1, x2, x3, x4 respectively

     eps=1e-16;
     Diff=x4-x3;
     oneoverL=1./sqrt(sum(Diff.*Diff,2));
     t=Diff.*[oneoverL oneoverL oneoverL];
     
     Diff=x2-x1;
     oneoverLp=1./sqrt(sum(Diff.*Diff,2));
     tp=Diff.*[oneoverLp oneoverLp oneoverLp];
     
     c=sum(t.*tp,2);
     flipL=0;
     for i=1:size(c,1)
         if c<0
             flipL=flipL+1;
             flip(flipL)=i;
             temp=x2(i,:);
             x2(i,:)=x1(i,:);
             x1(i,:)=temp;
             tp(i,:)=-tp(i,:);
             bp(i,:)=-bp(i,:);
         end
     end
     
     
     temp=sum((x2-x1).*t,2);
     x2mod=x1+[temp temp temp].*t;
     diff=(x2-x2mod);
     x1mod=x1+0.5.*diff;
     x2mod=x2mod+0.5.*diff;
     R=(x3-x1mod);
     Rdt=sum(R.*t,2);
     nd=R-[Rdt Rdt Rdt].*t;
     d2=sum(nd.*nd,2);
     
     r4=sum(x4.*t,2);
     r3=sum(x3.*t,2);
     s2=sum(x2mod.*t,2);
     s1=sum(x1mod.*t,2);
     
     y=[ r3,  r3,  r4,  r4];
     z=[-s1, -s2, -s1, -s2];
     
     a2=a*a;
     a2_d2 = a2+d2;
     temp=1./a2_d2;
     a2d2inv=[temp temp temp temp];
     ypz=y+z;
     ymz=y-z;
     Ra    = sqrt( [a2_d2 a2_d2 a2_d2 a2_d2] + ypz.*ypz);
     Rainv=1./Ra;
     Log_Ra_ypz=log(Ra+ypz);
        
     f_003=Ra.*a2d2inv;
     f_103=-0.5.*(Log_Ra_ypz - ymz.*Ra.*a2d2inv);
     f_013=-0.5.*(Log_Ra_ypz + ymz.*Ra.*a2d2inv);
     f_113=-Log_Ra_ypz;
     f_213=z.*Log_Ra_ypz - Ra;
     f_123=y.*Log_Ra_ypz - Ra;
        
     f_005=a2d2inv.*(2.*a2d2inv.*Ra - Rainv);
     f_105= a2d2inv.*(a2d2inv.*ymz.*Ra - y.*Rainv);
     f_015=-a2d2inv.*(a2d2inv.*ymz.*Ra + z.*Rainv);
     f_115=-a2d2inv.*ypz.*Rainv;
     f_215=  Rainv - z.*f_115;
     f_125=  Rainv - y.*f_115;
     
     mf=[1 -1 -1 1]';
     Fintegrals=[f_003*mf f_103*mf f_013*mf f_113*mf f_213*mf f_123*mf f_005*mf f_105*mf f_015*mf f_115*mf f_215*mf f_125*mf];
     %            1        2        3        4        5        6        7        8        9        10       11       12 
     m4p=0.25 * mu / pi;
     m8p=0.5 * m4p;
     m4pn=m4p / ( 1 - nu );
     a2m4pn=a2*m4pn;
     a2m8p=a2 * m8p;
     
     tdb=sum(t.*b,2);
     tdbv=[tdb tdb tdb];
     tdbp=sum(t.*bp,2);
     tdbpv=[tdbp tdbp tdbp];
     nddb=sum(nd.*b,2);
     nddbv=[nddb nddb nddb];
     bxt=[b(:,2).*t(:,3)-b(:,3).*t(:,2) , b(:,3).*t(:,1)-b(:,1).*t(:,3) , b(:,1).*t(:,2)-b(:,2).*t(:,1)];
     bpxt=[bp(:,2).*t(:,3)-bp(:,3).*t(:,2) , bp(:,3).*t(:,1)-bp(:,1).*t(:,3) , bp(:,1).*t(:,2)-bp(:,2).*t(:,1)];
     ndxt=[nd(:,2).*t(:,3)-nd(:,3).*t(:,2) , nd(:,3).*t(:,1)-nd(:,1).*t(:,3) , nd(:,1).*t(:,2)-nd(:,2).*t(:,1)];
     bpxtdb=sum(bpxt.*b,2);
     bpxtdnd=sum(bpxt.*nd,2);
     bpxtdndv=[bpxtdnd bpxtdnd bpxtdnd];
     bpxtxt=tdbpv.*t - bp;
     
     I_003=m4pn.*(nddbv.*bpxtxt + [bpxtdb bpxtdb bpxtdb].*ndxt - bpxtdndv.*bxt) - m4p.*tdbv.*tdbpv.*nd; 
     I_113= (m4pn-m4p).*tdbv.*bpxtxt;
     I_005=-a2m8p.*tdbv.*tdbpv.*nd - a2m4pn.*bpxtdndv.*bxt - m4pn.*bpxtdndv.*nddbv.*ndxt;
     I_115=-a2m8p.*tdbv.*bpxtxt - m4pn.*bpxtdndv.*tdbv.*ndxt;
     
     
     Fint_003=Fintegrals(:,2)-y(:,1).*Fintegrals(:,1);
     Fint_113=Fintegrals(:,5)-y(:,1).*Fintegrals(:,4);
     Fint_005=Fintegrals(:,8)-y(:,1).*Fintegrals(:,7);
     Fint_115=Fintegrals(:,11)-y(:,1).*Fintegrals(:,10);
     
     f4=   I_003.*[Fint_003 Fint_003 Fint_003] + I_113.*[Fint_113 Fint_113 Fint_113]; 
     f4=f4+I_005.*[Fint_005 Fint_005 Fint_005] + I_115.*[Fint_115 Fint_115 Fint_115];
     f4=f4.*[oneoverL oneoverL oneoverL];
     
     Fint_003=y(:,3).*Fintegrals(:,1)-Fintegrals(:,2);
     Fint_113=y(:,3).*Fintegrals(:,4)-Fintegrals(:,5);
     Fint_005=y(:,3).*Fintegrals(:,7)-Fintegrals(:,8);
     Fint_115=y(:,3).*Fintegrals(:,10)-Fintegrals(:,11);
     
     f3=   I_003.*[Fint_003 Fint_003 Fint_003] + I_113.*[Fint_113 Fint_113 Fint_113]; 
     f3=f3+I_005.*[Fint_005 Fint_005 Fint_005] + I_115.*[Fint_115 Fint_115 Fint_115];
     f3=f3.*[oneoverL oneoverL oneoverL];
     
     corsize=0;
     for i=1:size(c,1)
         if (diff(i,:)*diff(i,:)')>(eps*(x2mod(i,:)*x2mod(i,:)'+x1mod(i,:)*x1mod(i,:)'))
             corsize=corsize+1;
             corindex(corsize)=i;
             x1mod2(corsize,:)=x1mod(i,:);
             x12(corsize,:)=x1(i,:);
             x2mod2(corsize,:)=x2mod(i,:);
             x22(corsize,:)=x2(i,:);
             x32(corsize,:)=x3(i,:);
             x42(corsize,:)=x4(i,:);
             bp2(corsize,:)=bp(i,:);
             b2(corsize,:)=b(i,:);
         end
     end
     if corsize>0
         [whocares1,whocares2,f3cor2,f4cor2]=remoteforce_analyt(mu,nu,bp2,x12,x1mod2,b2,x32,x42,a);
         [whocares1,whocares2,f3cor3,f4cor3]=remoteforce_analyt(mu,nu,bp2,x2mod2,x22,b2,x32,x42,a);
         f3cor=zeros(size(c,1),3);
         f4cor=zeros(size(c,1),3);
         for i=1:corsize
             index=corindex(i);
             f3cor(index,:)=f3cor2(i,:)+f3cor3(i,:);
             f4cor(index,:)=f4cor2(i,:)+f4cor3(i,:);
         end
         f3=f3+f3cor;
         f4=f4+f4cor;
     end
     
     
     
     temp=sum((x4-x3).*tp,2);
     x4mod=x3+[temp temp temp].*tp;
     diff=x4-x4mod;
     x3mod=x3+0.5.*diff;
     x4mod=x4mod+0.5.*diff;
     R=(x3mod-x1);
     Rdtp=sum(R.*tp,2);
     nd=R-[Rdtp Rdtp Rdtp].*tp;
     d2=sum(nd.*nd,2);
     r4=sum(x4mod.*tp,2);
     r3=sum(x3mod.*tp,2);
     s2=sum(x2.*tp,2);
     s1=sum(x1.*tp,2);
     
     y=[ r3,  r3,  r4,  r4];
     z=[-s1, -s2, -s1, -s2];
     
     a2=a*a;
     a2_d2 = a2+d2;
     temp=1./a2_d2;
     a2d2inv=[temp temp temp temp];
     ypz=y+z;
     ymz=y-z;
     Ra    = sqrt( [a2_d2 a2_d2 a2_d2 a2_d2] + ypz.*ypz);
     Rainv=1./Ra;
     Log_Ra_ypz=log(Ra+ypz);
        
     f_003=Ra.*a2d2inv;
     f_103=-0.5.*(Log_Ra_ypz - ymz.*Ra.*a2d2inv);
     f_013=-0.5.*(Log_Ra_ypz + ymz.*Ra.*a2d2inv);
     f_113=-Log_Ra_ypz;
     f_213=z.*Log_Ra_ypz - Ra;
     f_123=y.*Log_Ra_ypz - Ra;
        
     f_005=a2d2inv.*(2.*a2d2inv.*Ra - Rainv);
     f_105= a2d2inv.*(a2d2inv.*ymz.*Ra - y.*Rainv);
     f_015=-a2d2inv.*(a2d2inv.*ymz.*Ra + z.*Rainv);
     f_115=-a2d2inv.*ypz.*Rainv;
     f_215=  Rainv - z.*f_115;
     f_125=  Rainv - y.*f_115;
     
     mf=[1 -1 -1 1]';
     Fintegrals=[f_003*mf f_103*mf f_013*mf f_113*mf f_213*mf f_123*mf f_005*mf f_105*mf f_015*mf f_115*mf f_215*mf f_125*mf];
     %            1        2        3        4        5        6        7        8        9        10       11       12 
     
     tpdb=sum(tp.*b,2);
     tpdbv=[tpdb tpdb tpdb];
     tpdbp=sum(tp.*bp,2);
     tpdbpv=[tpdbp tpdbp tpdbp];
     nddbp=sum(nd.*bp,2);
     nddbpv=[nddbp nddbp nddbp];
     bxtp=[b(:,2).*tp(:,3)-b(:,3).*tp(:,2) , b(:,3).*tp(:,1)-b(:,1).*tp(:,3) , b(:,1).*tp(:,2)-b(:,2).*tp(:,1)];
     bpxtp=[bp(:,2).*tp(:,3)-bp(:,3).*tp(:,2) , bp(:,3).*tp(:,1)-bp(:,1).*tp(:,3) , bp(:,1).*tp(:,2)-bp(:,2).*tp(:,1)];
     ndxtp=[nd(:,2).*tp(:,3)-nd(:,3).*tp(:,2) , nd(:,3).*tp(:,1)-nd(:,1).*tp(:,3) , nd(:,1).*tp(:,2)-nd(:,2).*tp(:,1)];
     bxtpdbp=sum(bxtp.*bp,2);
     bxtpdnd=sum(bxtp.*nd,2);
     bxtpdndv=[bxtpdnd bxtpdnd bxtpdnd];
     bxtpxtp=tpdbv.*tp - b;
     
     I_003=m4pn.*(nddbpv.*bxtpxtp + [bxtpdbp bxtpdbp bxtpdbp].*ndxtp - bxtpdndv.*bpxtp) - m4p.*tpdbpv.*tpdbv.*nd; 
     I_113= (m4pn-m4p).*tpdbpv.*bxtpxtp;
     I_005=-a2m8p.*tpdbpv.*tpdbv.*nd - a2m4pn.*bxtpdndv.*bpxtp - m4pn.*bxtpdndv.*nddbpv.*ndxtp;
     I_115=-a2m8p.*tpdbpv.*bxtpxtp - m4pn.*bxtpdndv.*tpdbpv.*ndxtp;
     
     
     Fint_003=Fintegrals(:,3)-z(:,1).*Fintegrals(:,1);
     Fint_113=Fintegrals(:,6)-z(:,1).*Fintegrals(:,4);
     Fint_005=Fintegrals(:,9)-z(:,1).*Fintegrals(:,7);
     Fint_115=Fintegrals(:,12)-z(:,1).*Fintegrals(:,10);
     
     f2=   I_003.*[Fint_003 Fint_003 Fint_003] + I_113.*[Fint_113 Fint_113 Fint_113]; 
     f2=f2+I_005.*[Fint_005 Fint_005 Fint_005] + I_115.*[Fint_115 Fint_115 Fint_115];
     f2=f2.*[oneoverLp oneoverLp oneoverLp];
     
     Fint_003=z(:,2).*Fintegrals(:,1)-Fintegrals(:,3);
     Fint_113=z(:,2).*Fintegrals(:,4)-Fintegrals(:,6);
     Fint_005=z(:,2).*Fintegrals(:,7)-Fintegrals(:,9);
     Fint_115=z(:,2).*Fintegrals(:,10)-Fintegrals(:,12);
     
     f1=   I_003.*[Fint_003 Fint_003 Fint_003] + I_113.*[Fint_113 Fint_113 Fint_113]; 
     f1=f1+I_005.*[Fint_005 Fint_005 Fint_005] + I_115.*[Fint_115 Fint_115 Fint_115];
     f1=f1.*[oneoverLp oneoverLp oneoverLp];
     
     corsize=0;
     corindex=[];
     x22=[];
     x42=[];
     x4mod2=[];
     bp2=[];
     b2=[];
     for i=1:size(c,1)
         if (diff(i,:)*diff(i,:)')>(eps*(x4mod(i,:)*x4mod(i,:)'+x3mod(i,:)*x3mod(i,:)'))
             corsize=corsize+1;
             corindex(corsize)=i;
             x12(corsize,:)=x1(i,:);
             x22(corsize,:)=x2(i,:);
             x32(corsize,:)=x3(i,:);
             x3mod2(corsize,:)=x3mod(i,:);
             x42(corsize,:)=x4(i,:);
             x4mod2(corsize,:)=x4mod(i,:);
             bp2(corsize,:)=bp(i,:);
             b2(corsize,:)=b(i,:);
         end
     end
     if corsize>0
         [whocares1,whocares2,f1cor2,f2cor2]=remoteforce_analyt(mu,nu,b2,x32,x3mod2,bp2,x12,x22,a);
         [whocares1,whocares2,f1cor3,f2cor3]=remoteforce_analyt(mu,nu,b2,x4mod2,x42,bp2,x12,x22,a);
         f1cor=zeros(size(c,1),3);
         f2cor=zeros(size(c,1),3);
         for i=1:corsize
             index=corindex(i);
             f1cor(index,:)=f1cor2(i,:)+f1cor3(i,:);
             f2cor(index,:)=f2cor2(i,:)+f2cor3(i,:);
         end
         f1=f1+f1cor;
         f2=f2+f2cor;
     end
     
     for i=1:flipL
         index=flip(i);
         temp=x2(index,:);
         x2(index,:)=x1(index,:);
         x1(index,:)=temp;
         bp(index,:)=-bp(index,:);
         temp=f2(index,:);
         f2(index,:)=f1(index,:);
         f1(index,:)=temp;
     end 