function [f0,f1]=remoteforce_strint(MU,NU,b01,r0,r1,b23,r2,r3,a,nsub)
% Computes force on two nodes of segment r0-r1 (Burgers vector b01)
% due to segment r2-r3 (Burgers vector b23) by numerically integrating the 
% stress field of segment r2-r3 on segment r0-r1.
% MU is shear modulus, NU is Poisson ratio, a is core spread radius
% nsub is the subdivision points for numerical integration
%
% Geometry:
%   r0--------r1   r2-------r3

[mb,nb]=size(b01); [m0,n0]=size(r0); [m1,n1]=size(r1); 
if (mb<nb) | (m0<n0) | (m1<n1) 
    disp('selfforce: b, r0, r1, r2, r3 should be column vector');
end

r01=r1-r0; L01=norm(r01); e01=r01/L01;
alpha=([1:nsub]-0.5)/nsub;

strL01=zeros(nsub,3,3);
strL12=zeros(nsub,3,3);

for i=1:nsub
    r=r0+(r1-r0)*alpha(i);
    %Original implementation
    %s=calsegstr3da(MU, NU, b23, r2, r3, r, a);
    %A faster implementation
    s=calsegstr3dt(MU, NU, b23, r2, r3, r, a);
    strL01(i,:,:)=s;
end

s0=zeros(3,3); s1=s0;
for i=1:nsub,
    for j=1:3, for k=1:3,
    s0(j,k)=s0(j,k)+strL01(i,j,k)*(1-alpha(i));
    s1(j,k)=s1(j,k)+strL01(i,j,k)*alpha(i);
    end; end
end

f0=cross(s0*b01,r01)/nsub;
f1=cross(s1*b01,r01)/nsub;

%plot(strL01(:,1,2)); disp('press any key to continue...'); pause