function [fs0,fs1]=selfforce(MU,NU,b,r0,r1,a)

% Computes driving force on two end nodes of a segment due to self stress
% MU is shear modulus, NU is Poisson ratio, b(3) is Burgers vector
% r0(3) is position of one node, r1(3) is position of the other node
% a is core spread radius

[mb,nb]=size(b); [m0,n0]=size(r0); [m1,n1]=size(r1); 
if (mb<nb) | (m0<n0) | (m1<n1)
    disp('selfforce: b, r0, r1 should be column vector');
end

r01=r1-r0; L01=norm(r01); e01=r01/L01;

La=sqrt(L01*L01+a*a);

%screw Burgers vector
bs=dot(b,e01); 

%edge Burgers vector
be=b-bs*e01;

%wrong formula
%S=MU/4/pi/(1-NU) * (2*NU*La+(1-NU)*a*a/La-(1+NU)*a)/L01;

%S=NU*(2*(a-La)/L01+log((La+L01)/a))-(1-NU)*a^2/2*(-2*(1/a-1/La)/L01 + L01/a/a/La);
S=-(2*NU*La+(1-NU)*a*a/La-(1+NU)*a)/L01 + (NU*log((La+L01)/a)-(1-NU)/2*L01/La);
S=S*MU/4/pi/(1-NU);

fs01=be*bs*S;


fs0=-fs01;
fs1= fs01;

%fs0
%disp(sprintf('self force: bs=%25.15e be=%25.15e S=%25.15e',bs,norm(be),S));
