%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% testloop.m
%
% self-consistency check for a circular dislocation loop
% compute energy, and nodal driving force
% force are computed in three ways:
%  by numerically integrating stress field
%  by analytic formula (of the above integration)
%  by numerically differentiating energy
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Preparing the loop coordinates
N=6;
%N=12;
theta=[0:N-1]'/N*(2*pi);
R=10;

%circular loop
rn=R*[cos(theta),sin(theta),zeros(size(theta))]; %circular loop
b =[1 0 0]';                                     %glide loop

%random loop
%rn=R*rand(size(rn));                            %random loop
%b =rand(3,1);                                   %random loop

%Material constants
a=0.1;
MU=1;
NU=0.3;

%%%%%%%%%%%%%%%%%%%%%
% LOOPENERGY
%%%%%%%%%%%%%%%%%%%%%
%disp('loopenergy...');
%E0=loopenergy(MU,NU,b,rn,a);
%disp(sprintf('E0 = %25.15e\n',E0));

%********************
% LOOPNODEFORCE
%********************
%nsub =50;
%nsubn=2000;
nsub =50;
nsubn=1000;
Delta=1e-3;
i=2;
disp('loopnodeforce_strint...');
fns=loopnodeforce_strint(MU,NU,b,rn,a,nsub,nsubn);
disp('loopnodeforce_analyt...');
fna=loopnodeforce_analyt(MU,NU,b,rn,a);
disp('loopnodeforce_engdif...');
fne=loopnodeforce_engdif(MU,NU,b,rn,a,i,Delta);

disp(sprintf('loopnodeforce_strint f%d = (%25.15e,%25.15e,%25.15e)',i,fns(i,1),fns(i,2),fns(i,3)));
disp(sprintf('loopnodeforce_analyt f%d = (%25.15e,%25.15e,%25.15e)',i,fna(i,1),fna(i,2),fna(i,3)));
disp(sprintf('loopnodeforce_engdif f%d = (%25.15e,%25.15e,%25.15e)',i,fne(1),fne(2),fne(3)));


