%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% testloop2.m
%
% To generate results for the "non-singular" paper
%
% self-consistency check for a circular dislocation loop
% compute energy, and nodal driving force
% force are computed in two ways:
%  by integrating stress field (analytically)
%  by numerically differentiating energy
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Preparing the loop coordinates
%N=6;
N=12;
theta=[0:N-1]'/N*(2*pi);
R=10;

%circular loop
rn=R*[cos(theta),sin(theta),zeros(size(theta))]; %circular loop
b =[1 0 0]';                                     %glide loop

%for plotting
phi=[0:1000]'/1000*(2*pi);
rs=R*[cos(phi),sin(phi),zeros(size(phi))];

%random loop
%rn=R*rand(size(rn));                            %random loop
%b =rand(3,1);                                   %random loop

%Material constants
a=0.1;
MU=1;
NU=0.3;

%%%%%%%%%%%%%%%%%%%%%
% LOOPENERGY
%%%%%%%%%%%%%%%%%%%%%
disp('loopenergy...');
E0=loopenergy(MU,NU,b,rn,a);
disp(sprintf('E0 = %25.15e\n',E0));

%********************
% LOOPNODEFORCE
%********************
Delta=1e-2;
i=2;
disp('loopnodeforce_analyt...');
fna=loopnodeforce_analyt(MU,NU,b,rn,a);
disp('loopnodeforce_engdif...');
fne=loopnodeforce_engdif(MU,NU,b,rn,a,i,Delta);

disp(sprintf('loopnodeforce_analyt f%d = (%25.15e,%25.15e,%25.15e)',i,fna(i,1),fna(i,2),fna(i,3)));
disp(sprintf('loopnodeforce_engdif f%d = (%25.15e,%25.15e,%25.15e)',i,fne(1),fne(2),fne(3)));

fneall=loopnodeforce_engdif(MU,NU,b,rn,a,0,Delta);
disp(sprintf('maximum force difference: dfmax=%25.15e',max(sum((fneall-fna).*rn,2))));

fnar=sum((fna.*rn)/R,2);
fneallr=sum((fneall.*rn)/R,2);


figure(1);
plot(rn(:,1),rn(:,2),'ro',rn([1:N,1],1),rn([1:N,1],2),'b-',rs(:,1),rs(:,2),':');
axis equal
fs=24;
set(gca,'FontSize',fs);
xlabel('x');
ylabel('y');

figure(2);
plot(theta/(2*pi),fneallr,'ro-',theta/(2*pi),fnar,'b.');
fs=24;
set(gca,'FontSize',fs);
ylim([-0.4, -0.2]);
xlabel('\theta / (2\pi)');
ylabel('f_r');


