%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% testloop3.m
%
% To generate results for the "non-singular" paper
%
% test numerical convergence as discretization length shrink to zero
% compute total elastic energy, and nodal driving force by 
%  analytic integration of stress field
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Material constants
a=0.1;
MU=1;
NU=0.3;
b =[1 0 0]';                                     %glide loop

%
%Ntest = [ 6 12 100 200 500 600 1200 ];
Ntest=[ 1200];
Efsav = zeros(length(Ntest),3);
R = 10;

if(0)
for i = 1:length(Ntest),
   
N=Ntest(i);
   
%Preparing the loop coordinates
theta=[0:N-1]'/N*(2*pi);
R=10;

%circular loop
rn=R*[cos(theta),sin(theta),zeros(size(theta))]; %circular loop

%%%%%%%%%%%%%%%%%%%%%
% LOOPENERGY
%%%%%%%%%%%%%%%%%%%%%
disp('loopenergy...');
E0=loopenergy(MU,NU,b,rn,a);
disp(sprintf('E0 = %25.15e\n',E0));

%********************
% LOOPNODEFORCE
%********************
Delta=1e-2;
disp('loopnodeforce_analyt...');
fna=loopnodeforce_analyt(MU,NU,b,rn,a);

fr=sum(sum((fna.*rn)/R,2));

[E0,fr]

Efsav(i,:)=[N,E0,fr];
end

else
   
Efsav=[
  6   2.703323083991060e+001   -3.281273419402578e+000
  12  2.898016747353339e+001   -3.497372323131243e+000
  100 2.968101580305298e+001   -3.574996972221014e+000
  200 2.968976829310166e+001   -3.575988464757091e+000
  400 2.969199377954858e+001   -3.576246177055714e+000
  500 2.969226111496175e+001   -3.576277579833478e+000
  600 2.969240609665381e+001   -3.576294651794418e+000
 1200 2.969265243948877e+001   -3.576323645881539e+000
];
   
end

Wanl=2*pi*R/(8*pi)*((2-NU)/(1-NU)*(log(8*R/a)-2)+1/2);
fanl=-1/4*((2-NU)/(1-NU)*(log(8*R/a)-1)+1/2);

figure(1);
plot(Efsav(2:end-1,1),Efsav(2:end-1,2),'o-',[0 600],[1 1]*Wanl,'--');
fs=24;
set(gca,'FontSize',fs);
title('W^{GL}');
xlabel('N');

figure(2);
plot(Efsav(2:end-1,1),Efsav(2:end-1,3),'o-',[0 600],[1 1]*fanl,'--');
fs=24;
set(gca,'FontSize',fs);
xlabel('N');
title('f^{GL}_R');

figure(3);
p3=loglog(Efsav(2:end-1,1),abs((Efsav(2:end-1,2)-Efsav(end,2))/Efsav(end,2)),'x-',...
   Efsav(2:end-1,1),abs((Efsav(2:end-1,3)-Efsav(end,3))/Efsav(end,3)),'ro');
set(p3(1),'MarkerSize',16);
set(p3(2),'MarkerSize',16);
fs=24;
set(gca,'FontSize',fs);
%title('W^{GL}');
xlabel('N');

%figure(4);
%loglog(Efsav(2:end-1,1),abs((Efsav(2:end-1,3)-Efsav(end,3))/Efsav(end,3)),'o-');
%fs=24;
%set(gca,'FontSize',fs);
%xlabel('N');
%title('f^{GL}_R');

