%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% testloop4.m
%
% To generate results for the "non-singular" paper
%
% distribution of node force on a circular glide loop
% compare with Gavazza-Barnett, Brown and Lothe formula
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Preparing the loop coordinates
N=32;
theta=[0:N-1]'/N*(2*pi);
R=10;

%circular loop
rn=R*[cos(theta),sin(theta),zeros(size(theta))]; %circular loop
b =[1 0 0]';                                     %glide loop

%for plotting
phi=[0:1000]'/1000*(2*pi);
rs=R*[cos(phi),sin(phi),zeros(size(phi))];

%Material constants
a=0.1;
MU=1;
NU=0.3;

%********************
% LOOPNODEFORCE
%********************
Delta=1e-2;
disp('loopnodeforce_analyt...');
fna=loopnodeforce_analyt(MU,NU,b,rn,a);

fnar=sum((fna.*rn)/R,2) * (N/(2*pi*R));

figure(1);
plot(rn(:,1),rn(:,2),'ro',rn([1:N,1],1),rn([1:N,1],2),'b-',rs(:,1),rs(:,2),':');
axis equal
fs=24;
set(gca,'FontSize',fs);
xlabel('x');
ylabel('y');

figure(2);
plot(theta/(2*pi),fnar,'b.-');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');
%title('f_r');
t2=text(0.9,-0.03,'f_r');set(t2,'FontSize',fs);
ylim([-0.08 -0.02]);

