%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% testloop4.m
%
% To generate results for the "non-singular" paper
%
% distribution of node force on a circular glide loop
% compare with Gavazza-Barnett, Brown and Lothe formula
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Preparing the loop coordinates
N=100;
theta=[0:N-1]'/N*(2*pi);
R=10;

%circular loop
rn=R*[cos(theta),sin(theta),zeros(size(theta))]; %circular loop
b =[1 0 0]';                                     %glide loop

%Material constants
a=0.1;
MU=1;
NU=0.3;

alpha=theta+pi/2;
Et=MU*sum(b.^2)/4/pi * (cos(alpha).^2 + sin(alpha).^2/(1-NU));
FnF2=MU/(8*pi*(1-NU)) * sum(b.^2) * cos(alpha).^2 * (1/2/(1-NU)-1);

%********************
% LOOPNODEFORCE
%********************
if(1)
Delta=1e-2;
disp('loopnodeforce_analyt...');
fna=loopnodeforce_analyt(MU,NU,b,rn,a);
fnar=sum((fna.*rn)/R,2) * (N/(2*pi*R));

figure(2);
plot(theta/(2*pi),Et/R,'b.-',theta/(2*pi),FnF2/R,'r.-');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');

figure(3);
plot(theta/(2*pi),fnar,'b.-');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');
%title('f_r');
t2=text(0.9,-0.03,'f_r');set(t2,'FontSize',fs);
ylim([-0.08 -0.02]);

end

%********************
% BROWN's APPROACH
%********************

%Preparing the loop coordinates
rho=a;
dl=0.25*rho;
N2=round(2*pi*R/dl);
theta2=[0:N2-1]'/N2*(2*pi);

disp(sprintf('rho=%e dl=%e N2=%d',rho,dl,N2));

%circular loop
rn2=R*[cos(theta2),sin(theta2),zeros(size(theta2))]; %circular loop

%the place where the force is calculated
N1=64;
phi=[0:N1-1]'/N1*(2*pi);
R=10;
rf=R*[cos(phi),sin(phi),zeros(size(phi))]; %circular loop
xi=[-sin(phi),cos(phi),zeros(size(phi))];  %line direction

fbrown=zeros(size(rf));

for i=1:N1,
   disp(sprintf('i=%d N1=%d',i,N1));
   rm=rf(i,:)'*(R-rho)/R;
   rp=rf(i,:)'*(R+rho)/R;
   sigm=loopstress(MU,NU,b,rn2,a,rm);
   sigp=loopstress(MU,NU,b,rn2,a,rp);
   sig=(sigm+sigp)/2;
   fbrown(i,:)=cross(sig*b,xi(i,:)')';
end

fbrownr=sum((fbrown.*rf)/R,2);

alpha=phi+pi/2;
Et=MU*sum(b.^2)/4/pi * (cos(alpha).^2 + sin(alpha).^2/(1-NU));
FnF2=MU/(8*pi*(1-NU)) * sum(b.^2) * cos(alpha).^2 * (1/2/(1-NU)-1);

fGBr=fbrownr+(Et-FnF2)/R;
fhirthr=fbrownr+Et/R;

%figure(4);
figure(3); hold on

plot(phi/(2*pi),fbrownr,'m.-', phi/(2*pi),fGBr, 'r.-', phi/(2*pi),fhirthr, 'k.-');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');
ylabel('f_{brown}');

hold off