%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% testloop6.m
%
% To generate results for the "non-singular" paper
%
% distribution of node force on a circular glide loop
% compare with Gavazza-Barnett, Brown and Lothe formula
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if(1)
   load tl6
else   
   
%Preparing the loop coordinates
N=100;
theta=[0:N-1]'/N*(2*pi);
R=10;

%circular loop
rn=R*[cos(theta),sin(theta),zeros(size(theta))]; %circular loop
b =[1 0 0]';                                     %glide loop

%Material constants
a=0.1;
MU=1;
NU=0.3;

alpha=theta+pi/2;
Et=MU*sum(b.^2)/4/pi * (cos(alpha).^2 + sin(alpha).^2/(1-NU));
FnF2=MU/(8*pi*(1-NU)) * sum(b.^2) * (sin(alpha).^2+2*cos(2*alpha)) * (1/2/(1-NU)-1);

%********************
% LOOPNODEFORCE
%********************
if(1)
Delta=1e-2;
disp('loopnodeforce_analyt...');
fna=loopnodeforce_analyt(MU,NU,b,rn,a);
fnar=sum((fna.*rn)/R,2) * (N/(2*pi*R));  %force per unit length

figure(2);
plot(theta/(2*pi),Et/R,'b.-',theta/(2*pi),FnF2/R,'r.-');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');

figure(3);
plot(theta/(2*pi),fnar,'b.-');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');
%title('f_r');
t2=text(0.9,-0.03,'f_r');set(t2,'FontSize',fs);
ylim([-0.08 -0.02]);

end

%********************
% BROWN's APPROACH
%********************

%Preparing the loop coordinates
rho=a;
dl=0.25*rho;
N2=round(2*pi*R/dl);
theta2=[0:N2-1]'/N2*(2*pi);

disp(sprintf('rho=%e dl=%e N2=%d',rho,dl,N2));

%circular loop
rn2=R*[cos(theta2),sin(theta2),zeros(size(theta2))]; %circular loop

%the place where the force is calculated
N1=64;
phi=[0:N1-1]'/N1*(2*pi);
R=10;
rf=R*[cos(phi),sin(phi),zeros(size(phi))]; %circular loop
xi=[-sin(phi),cos(phi),zeros(size(phi))];  %line direction

fbrown=zeros(size(rf));

%when using the Brown's approach we need to use the original singular expressions (a=0)
for i=1:N1,
   disp(sprintf('i=%d N1=%d',i,N1));
   rm=rf(i,:)'*(R-rho)/R;
   rp=rf(i,:)'*(R+rho)/R;
   sigm=loopstress(MU,NU,b,rn2,0,rm);
   sigp=loopstress(MU,NU,b,rn2,0,rp);
   sig=(sigm+sigp)/2;
   fbrown(i,:)=cross(sig*b,xi(i,:)')';
end

end

fbrownr=sum((fbrown.*rf)/R,2);

alpha=phi+pi/2;
Et=MU*sum(b.^2)/4/pi * (cos(alpha).^2 + sin(alpha).^2/(1-NU));
FnF2=MU/(8*pi*(1-NU)) * sum(b.^2) * (sin(alpha).^2+2*cos(2*alpha)) * (1/2/(1-NU)-1);

fGBr=fbrownr+(Et-FnF2)/R;

fhirthr=fbrownr+Et/R;


figure(3);
plot(theta/(2*pi),fnar,'b.-', phi/(2*pi),fhirthr,'m-');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');
%title('f_r');
t2=text(0.9,-0.03,'f_r');set(t2,'FontSize',fs);
ylim([-0.1 -0.02]);


% added by CRW

Ecoreedge = MU*sum(b.^2)/16/pi * (1-2*NU)/(1-NU)^2;
Ecorescrew = MU*sum(b.^2)/8/pi;

fcor = fGBr - ( (cos(alpha).^2-2*cos(2*alpha)) * Ecorescrew + ...
   (sin(alpha).^2+2*cos(2*alpha)) * Ecoreedge ) / R;


%figure(4);
figure(3); hold on

offset=fnar(1)-fcor(1);
offset2=fnar(1)-fGBr(1);
plot(phi/(2*pi),fcor,'g.-', phi/(2*pi),fGBr, 'r.-');
%plot(phi/(2*pi),fcor+offset,'g--', phi/(2*pi),fGBr+offset2, 'r--');
fs=24;
set(gca,'FontSize',fs);
xlabel('\theta / (2\pi)');
ylabel('f_{brown}');

hold off

figure(4);
fcore=fcor-fGBr;
p4=plot(theta/(2*pi),fnar,'b-', phi/(2*pi),fcor,'bo', ...
   phi/(2*pi),fGBr, 'b--', phi/(2*pi), fcore, 'b-');
set(p4(4),'LineWidth',2);
fs=17;
set(gca,'FontSize',fs);
xlabel('\phi / (2\pi)');
ylabel('f');






%Mathematica line
%FullSimplify[ Series[ Simplify[ Integrate[ Cos[phi]/Sqrt[ 4*Sin[phi/2]^2 + c^2 ], {phi,0,2*Pi} ] , c>0 ], {c,0,2}] ]
%
%FullSimplify[ Series[ Simplify[ Integrate[ 4*Sin[phi/2]^4/Sqrt[ 4*Sin[phi/2]^2 + c^2 ]^3, {phi,0,2*Pi} ] , c>0 ], {c,0,2}] ]
