%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% testtetra.m
%
% self-consistency check for a random dislocation tetrahedra
% compute energy, and nodal driving force
% force are computed in three ways:
%  by numerically integrating stress field
%  by analytic formula (of the above integration)
%  by numerically differentiating energy
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%Preparing the dislocation coordinates
N=4;
R=10;

%random tetrahedra
rn=R*rand(N,3);  
b12=rand(3,1);
b13=rand(3,1);
b23=rand(3,1);
b14=0-b12-b13;
b24=0+b12-b23;
b34=0+b13+b23;
links=[ %tetrahedra
   1 2 b12' ;
   1 3 b13' ;
   1 4 b14' ;
   2 3 b23' ;
   2 4 b24' ;
   3 4 b34' 
   ];
   
%links=[ %loop
%   1 2 b12' ;
%   2 3 b12' ;
%   3 4 b12' ;
%   4 1 b12' 
%   ];

%Material constants
a=0.1;
MU=1;
NU=0.3;
sigext=zeros(3,3);

%%%%%%%%%%%%%%%%%%%%%
% ELASTICENERGY
%%%%%%%%%%%%%%%%%%%%%
disp('elasticenergy...');
E0=elasticenergy(MU,NU,a,rn,links);
disp(sprintf('E0 = %25.15e\n',E0));

%********************
% NODEFORCE
%********************
%nsub =50;
%nsubn=2000;
%nsub =50;
%nsubn=1000;
nsub=200;
nsubn=1000;
Delta=1e-3;
i=2;
disp('nodeforce_strint...');
t=cputime;
fns=nodeforce_strint(MU,NU,a,rn,links,nsub,nsubn,sigext);
cputime-t
disp('nodeforce_analyt...');
t=cputime;
fna=nodeforce_analyt(MU,NU,a,rn,links,sigext);
cputime-t
disp('nodeforce_engdif...');
t=cputime;
fne=nodeforce_engdif(MU,NU,a,rn,links,i,Delta);
cputime-t

disp(sprintf('nodeforce_strint f%d = (%25.15e,%25.15e,%25.15e)',i,fns(i,1),fns(i,2),fns(i,3)));
disp(sprintf('nodeforce_analyt f%d = (%25.15e,%25.15e,%25.15e)',i,fna(i,1),fna(i,2),fna(i,3)));
disp(sprintf('nodeforce_engdif f%d = (%25.15e,%25.15e,%25.15e)',i,fne(1),fne(2),fne(3)));


